/*******************************************************************************
 * UrnDaoIf.java
 * 
 * Copyright (c) 2010-2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Marcus Klein -- German National Library
 * 
 **********************************************************************/

/* ********************************************************************
 * CHANGELOG:
 * 
 * 2012-03-15 Commented and ported to Apache Maven - K. Kocer
 * ********************************************************************/

package org.nbnResolving.database.dao;

import java.util.List;

import org.nbnResolving.database.model.TableURN;

/**
 * EPICUR: Tabelle URN (DAO Interface)
 * 
 * @author t_kleinm, German National Library 11.05.2011
 */
public interface UrnDaoIf
{

	/**
	 * @param urnId
	 * @return <TableURN>
	 * @author kleinm, German National Library
	 */
	public TableURN getUrnById(long urnId);

	/**
	 * @param nsId
	 * @return List<TableURN>
	 * @author kleinm, German National Library
	 */
	public List<TableURN> getUrnsByNsId(int nsId);

	/**
	 * @param nsId
	 * @return List<TableURN>
	 * @author kleinm, German National Library
	 */
	public List<TableURN> getReservedUrnsByNsId(int nsId);

	/**
	 * @param nsId
	 * @return List<TableURN>
	 * @author kleinm, German National Library
	 */
	public List<TableURN> getRegisteredUrnsByNsId(int nsId);

	/**
	 * @param urnStr
	 *            Urn-Teilstring
	 * @return List<TableURN>
	 * @author t_kleinm, German National Library
	 */
	public List<TableURN> getUrnsByUrn(String urnStr);

	/**
	 * @param urnStr
	 *            Urn-Teilstring
	 * @return List<TableURN>
	 * @author t_kleinm, German National Library
	 */
	public List<TableURN> getReservedUrnsByUrn(String urnStr);

	/**
	 * @param urnStr
	 *            Urn-Teilstring
	 * @return List<TableURN>
	 * @author t_kleinm, German National Library
	 */
	public List<TableURN> getRegisteredUrnsByUrn(String urnStr);

	/**
	 * @param urnStr
	 *            vollständige URN
	 * @return List<TableURN>
	 * @author t_kleinm, German National Library
	 */
	public TableURN getUrnByUrn(String urnStr);

	/**
	 * @param urnStr
	 *            Urn-Teilstring
	 * @return Anzahl Urls
	 * @author t_kleinm, German National Library
	 */
	public int getNumberOfUrnsByUrn(String urnStr);

	/**
	 * @param nsId
	 * @return Anzahl reservierter URNs
	 * @author t_kleinm, German National Library
	 */
	public int getNumberOfReservedUrnsByNsId(int nsId);

	/**
	 * @param nsId
	 * @return Anzahl registrierter URNs
	 * @author t_kleinm, German National Library
	 */
	public int getNumberOfRegisteredUrnsByNsId(int nsId);

	/**
	 * @param urn
	 * @author kleinm, German National Library
	 */
	public void updateUrn(TableURN urn);

	/**
	 * @param urn
	 * @return urnId
	 * @author kleinm, German National Library
	 */
	public long insertUrn(TableURN urn);

}
