/**********************************************************************
 * Class TableURL
 * 
 * Copyright (c) 2010-2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

/* ********************************************************************
 * CHANGELOG:
 * 
 * 2012-03-15 Commented and ported to Apache Maven
 * Default values for all attributes (-1 for all numeric ones) 2011-04-08
 * Created on 2010-07-27 by Karaca Kocer
 ********************************************************************/

package org.nbnResolving.database.model;

import java.util.Date;

/**
 * A simple class modeling 1:1 the existing Sybase
 * RMDS table URL in epicur database.
 * For more information please see the database model.
 * 
 * @author Kadir Karaca Kocer
 */

public class TableURL {
	String   url = "Not set";
	long     urn_id = -1;         //RDBMS intern generated id of the URN
	int      mimetype_id = -1;    //foreign key
	boolean  is_primary = false;  //1: yes
	boolean  n2c = false;         //1: yes
	byte     origin = -1;         //3: transfer, 2: extern, 1: archive, 0: original
	int      institution_id = -1; //foreign key
	byte     status = -1;         //3: active, 2: temporary, 1: permanent, 0: blocked
	Date     blocking_time = null;//??
	String   checksum = null;     //MD5
	boolean  checksum_error = false; //1: yes
	boolean  checksum_check = false; //1: yes
	long     filesize = -1;          //Size of the file in bytes (0 -> not set/not known)
	boolean  url_check = true;       //1: yes
	int      url_error = -1;         //may be HTTP status code?
	Date     last_url_check = null;  //timestamp of last URL check
	Date     last_checksum_check = null; //timestamp of last checksum
	Date     created = new Date();       //date this record created. Default: NOW!
	Date     last_modified = new Date(); //date this record last modified
	String   comment = null;   //human readable comments about this record

	
	//some thoughts for future extensions
	int      input_way = -1;      //1: OAI-PMH, 2:Web-Form ... etc.
	Date     last_good = null;    //timestamp of last successfull check
	byte     error_count = -1;    //how many errors are occured
	TableINSTITUTION institution = null; //which institution is responsible
	String   mimeType = null;
	
	/**
	 * @return the url
	 */
	public String getUrl() {
		return this.url;
	}
	
	/**
	 * @param url the url to set
	 */
	public void setUrl(String url) {
		this.url = url;
	}
	
	/**
	 * @return the urn_id
	 */
	public long getUrn_id() {
		return this.urn_id;
	}
	
	/**
	 * @param urn_id the urn_id to set
	 */
	public void setUrn_id(long urn_id) {
		this.urn_id = urn_id;
	}
	
	/**
	 * @return the mimetype_id
	 */
	public int getMimetype_id() {
		return this.mimetype_id;
	}
	
	/**
	 * @param mimetype_id the mimetype_id to set
	 */
	public void setMimetype_id(int mimetype_id) {
		this.mimetype_id = mimetype_id;
	}
	
	/**
	 * @return the is_primary
	 */
	public boolean isIs_primary() {
		return this.is_primary;
	}
	
	/**
	 * @param is_primary the is_primary to set
	 */
	public void setIs_primary(boolean is_primary) {
		this.is_primary = is_primary;
	}
	
	/**
	 * @return the n2c
	 */
	public boolean isN2c() {
		return this.n2c;
	}
	
	/**
	 * @param n2c the n2c to set
	 */
	public void setN2c(boolean n2c) {
		this.n2c = n2c;
	}
	
	/**
	 * @return the origin
	 */
	public byte getOrigin() {
		return this.origin;
	}
	
	/**
	 * @param origin the origin to set
	 */
	public void setOrigin(byte origin) {
		this.origin = origin;
	}
	
	/**
	 * @return the institution_id
	 */
	public int getInstitution_id() {
		return this.institution_id;
	}
	
	/**
	 * @param institution_id the institution_id to set
	 */
	public void setInstitution_id(int institution_id) {
		this.institution_id = institution_id;
	}
	
	/**
	 * @return the status
	 */
	public byte getStatus() {
		return this.status;
	}
	
	/**
	 * @param status the status to set
	 */
	public void setStatus(byte status) {
		this.status = status;
	}
	
	/**
	 * @return the blocking_time
	 */
	public Date getBlocking_time() {
		return this.blocking_time;
	}
	
	/**
	 * @param blocking_time the blocking_time to set
	 */
	public void setBlocking_time(Date blocking_time) {
		this.blocking_time = blocking_time;
	}
	
	/**
	 * @return the checksum
	 */
	public String getChecksum() {
		return this.checksum;
	}
	
	/**
	 * @param checksum the checksum to set
	 */
	public void setChecksum(String checksum) {
		this.checksum = checksum;
	}
	
	/**
	 * @return the checksum_error
	 */
	public boolean isChecksum_error() {
		return this.checksum_error;
	}
	
	/**
	 * @param checksum_error the checksum_error to set
	 */
	public void setChecksum_error(boolean checksum_error) {
		this.checksum_error = checksum_error;
	}
	
	/**
	 * @return the checksum_check
	 */
	public boolean isChecksum_check() {
		return this.checksum_check;
	}
	
	/**
	 * @param checksum_check the checksum_check to set
	 */
	public void setChecksum_check(boolean checksum_check) {
		this.checksum_check = checksum_check;
	}
	
	/**
	 * @return the filesize
	 */
	public long getFilesize() {
		return this.filesize;
	}
	
	/**
	 * @param filesize the filesize to set
	 */
	public void setFilesize(long filesize) {
		this.filesize = filesize;
	}
	
	/**
	 * @return the url_check
	 */
	public boolean isUrl_check() {
		return this.url_check;
	}
	
	/**
	 * @param url_check the url_check to set
	 */
	public void setUrl_check(boolean url_check) {
		this.url_check = url_check;
	}
	
	/**
	 * @return the url_error
	 */
	public int getUrl_error() {
		return this.url_error;
	}
	
	/**
	 * @param url_error the url_error to set
	 */
	public void setUrl_error(int url_error) {
		this.url_error = url_error;
	}
	
	/**
	 * @return the last_url_check
	 */
	public Date getLast_url_check() {
		return this.last_url_check;
	}
	
	/**
	 * @param last_url_check the last_url_check to set
	 */
	public void setLast_url_check(Date last_url_check) {
		this.last_url_check = last_url_check;
	}
	
	/**
	 * @return the last_checksum_check
	 */
	public Date getLast_checksum_check() {
		return this.last_checksum_check;
	}
	
	/**
	 * @param last_checksum_check the last_checksum_check to set
	 */
	public void setLast_checksum_check(Date last_checksum_check) {
		this.last_checksum_check = last_checksum_check;
	}
	
	/**
	 * @return the created
	 */
	public Date getCreated() {
		return this.created;
	}
	
	/**
	 * @param created the created to set
	 */
	public void setCreated(Date created) {
		this.created = created;
	}
	
	/**
	 * @return the last_modified
	 */
	public Date getLast_modified() {
		return this.last_modified;
	}
	
	/**
	 * @param last_modified the last_modified to set
	 */
	public void setLast_modified(Date last_modified) {
		this.last_modified = last_modified;
	}
	
	/**
	 * @return the comment
	 */
	public String getComment() {
		return this.comment;
	}
	
	/**
	 * @param comment the comment to set
	 */
	public void setComment(String comment) {
		this.comment = comment;
	}
	
	/**
	 * @return the input_way
	 */
	public int getInput_way() {
		return this.input_way;
	}
	
	/**
	 * @param input_way the input_way to set
	 */
	public void setInput_way(int input_way) {
		this.input_way = input_way;
	}
	
	/**
	 * @return the last_good
	 */
	public Date getLast_good() {
		return this.last_good;
	}
	
	/**
	 * @param last_good the last_good to set
	 */
	public void setLast_good(Date last_good) {
		this.last_good = last_good;
	}
	
	/**
	 * @return the error_count
	 */
	public byte getError_count() {
		return this.error_count;
	}
	
	/**
	 * @param error_count the error_count to set
	 */
	public void setError_count(byte error_count) {
		this.error_count = error_count;
	}
	
	/**
	 * @return the institution
	 */
	public TableINSTITUTION getInstitution() {
		return this.institution;
	}
	
	/**
	 * @param institution the institution to set
	 */
	public void setInstitution(TableINSTITUTION institution) {
		this.institution = institution;
	}
	
	/**
	 * @return the mimeType
	 */
	public String getMimeType() {
		return this.mimeType;
	}
	
	/**
	 * @param mimeType the mimeType to set
	 */
	public void setMimeType(String mimeType) {
		this.mimeType = mimeType;
	}
}
